@@ -7,4 +7,8 @@ class DingDingOptionsForm(forms.Form):
     access_token = forms.CharField(
         max_length=255,
         help_text='DingTalk robot access_token'
-    )
\ No newline at end of file
+    )
+    keyword = forms.CharField(
+        max_length=255,
+        help_text='DingTalk robot key-word'
+    )
